@@ -7,7 +7,7 @@ import termplotlib as tpl
 
 
 @pytest.mark.skipif(
-    sys.stdout.encoding not in ["UTF-8", "UTF8"],
+    sys.stdout.encoding.upper() not in ["UTF-8", "UTF8"],
     reason=f"Need UTF-8 terminal (not {sys.stdout.encoding})",
 )
 def test_horizontal():
@@ -64,7 +64,7 @@ def test_horizontal_ascii():
 
 
 @pytest.mark.skipif(
-    sys.stdout.encoding not in ["UTF-8", "UTF8"],
+    sys.stdout.encoding.upper() not in ["UTF-8", "UTF8"],
     reason=f"Need UTF-8 terminal (not {sys.stdout.encoding})",
 )
 def test_vertical():
@@ -124,7 +124,7 @@ def test_vertical_ascii():
 
 
 @pytest.mark.skipif(
-    sys.stdout.encoding not in ["UTF-8", "UTF8"],
+    sys.stdout.encoding.upper() not in ["UTF-8", "UTF8"],
     reason=f"Need UTF-8 terminal (not {sys.stdout.encoding})",
 )
 def test_vertical_grid():
@@ -155,7 +155,7 @@ def test_vertical_grid():
 
 
 @pytest.mark.skipif(
-    sys.stdout.encoding not in ["UTF-8", "UTF8"],
+    sys.stdout.encoding.upper() not in ["UTF-8", "UTF8"],
     reason=f"Need UTF-8 terminal (not {sys.stdout.encoding})",
 )
 def test_vertical_strip():
